#!/usr/bin/python3
# encoding=utf-8

#C Dietmar Wimmer 2015
#Auslesen eines SFR02 Ultraschallsensor mittels RaspberryPi und senden des Ergebniss an Loxone Miniserver

#Import verschiedener Libraries
import smbus
import socket
import configparser
import urllib.parse
import time
from time import sleep

def main():
	# ---------------------------------------------
	# Globale Variablen
	# ---------------------------------------------
	separator = ";"

# ---------------------------------------------
# Durchsuche PlugIn config file
# ---------------------------------------------
pluginconfig = configparser.ConfigParser()
pluginconfig.read("/opt/loxberry/config/plugins/ultraschall/ultraschall.cfg")

enabled = pluginconfig.get('ultraschall', 'ENABLED')
miniservername = pluginconfig.get('ultraschall', 'MINISERVER')
virtualUDPPort = int(pluginconfig.get('ultraschall', 'UDPPORT'))


# ---------------------------------------------
# Durchsuche Loxberry config file
# ---------------------------------------------
loxberryconfig = configparser.ConfigParser()
loxberryconfig.read("/opt/loxberry/config/system/general.cfg")

miniserverIP = loxberryconfig.get(miniservername, 'IPADDRESS')

# ---------------------------------------------
# Exit wenn PlugIn nicht eingeschalten ist
# ---------------------------------------------
if enabled != "1":
	sys.exit(-1)


# ----------------------------------------------------------------------------------------------------
# Starte neue Entfernungsmessung
#-----------------------------------------------------------------------------------------------------
	
# -------------------------------------------------------------
# Definieren der Variablen und Konstanten des SRF02 i2c Sensors
# -------------------------------------------------------------
	
Busnummer = 1
Adresse_SRF02 = 0x70
Start = 0x51
High_Byte = 0
Low_Byte = 0
Entfernung = 0
sock = socket.socket( socket.AF_INET, socket.SOCK_DGRAM )

# ---------------------------------------------
# Instanzieren eines I2C Objektes
# ---------------------------------------------
i2cBus = smbus.SMBus(Busnummer)

# ---------------------------------------------
# Entfernungsmessung
# ---------------------------------------------
while True:
	
	print ('Start der Messung')
	i2cBus.write_byte_data(Adresse_SRF02, 0x00, 0x51)
	sleep(1)
	#Sleep absichtlich vor dem Lesen der Daten, da es je nach Entfernung ca. 65ms
	#dauern kann, bis das Ergebnis ermittelt und in das Register geschrieben wurde.
	#Mchte man ein schnelleres Abtasten der Entfernung haben, kann man den Wert
	#z.B. auf 100ms stellen  sleep(0.1)
	High_Byte = i2cBus.read_byte_data(Adresse_SRF02, 0x02)
	Low_Byte = i2cBus.read_byte_data(Adresse_SRF02, 0x03)
	if High_Byte == 0:

		Entfernung = Low_Byte

	else:

		Entfernung = (High_Byte*256)+Low_Byte 

	print ('High_Byte %d' % High_Byte)
	print ('Low_Byte %d' % Low_Byte)
	print ('Entfernung %d' % Entfernung)
	#print (miniserverIP)
	#print (virtualUDPPort)
	sock.sendto(str(Entfernung+0).encode('utf-8'), (miniserverIP,virtualUDPPort))	#Hhe der Dose - Gemessen wird ab der Unterkante der Feuchtraumdose (+9cm)
	sleep(15)

main()